CodeMirror: Groovy demonstration

Demonstration of CodeMirror's Groovy highlighter.

Created by eXo Platform SAS (license).

Note that the files for this parser aren't included in the CodeMirror repository, but have to fetched from svn.exoplatform.org:

- tokenizegroovy.js
- parsegroovy.js
- groovy.colors.css

// simple groovy script import javax.ws.rs.Path import javax.ws.rs.GET import javax.ws.rs.PathParam import javax.ws.rs.POST @Path("/") public class HelloWorld { @GET @Path("helloworld/{name}") public String hello(@PathParam("name") String name) { return "Hello " + name } @POST @Path("helloworld/{name}") public String hello2(@PathParam("name") String name) { return "Hello " + name } }